from pbpstats.data_loader.abs_data_loader import check_file_directory
from pbpstats.data_loader.live.file_loader import LiveFileLoader


class LivePbpFileLoader(LiveFileLoader):
    """
    A ``LivePbpFileLoader`` object should be instantiated and passed into ``LivePbpLoader`` when loading data from file

    :param str game_id: NBA Stats Game Id
    :param str file_directory:
        Directory in which data should be loaded from.
        The specific file location will be `live_<game_id>.json` in the `/pbp` subdirectory.
    """

    def __init__(self, file_directory):
        self.file_directory = file_directory

    @check_file_directory
    def load_data(self, game_id):
        self.game_id = game_id
        self.file_path = f"{self.file_directory}/pbp/live_{self.game_id}.json"
        return self._load_data_from_file()



import requests

from pbpstats import REQUEST_TIMEOUT
from pbpstats.data_loader.data_nba.base import DataNbaLoaderBase


class DataNbaWebLoader(DataNbaLoaderBase):
    """
    Base class for loading data from data.nba.com API request.

    All data.nba.com data loader classes should inherit from this class.

    This class should not be instantiated directly.
    """

    def _load_request_data(self):
        response = requests.get(self.url, timeout=REQUEST_TIMEOUT)
        if response.status_code == 200:
            self.source_data = response.json()
            self._save_data_to_file()
            return self.source_data
        else:
            response.raise_for_status()



from pbpstats.resources.enhanced_pbp import JumpBall
from pbpstats.resources.enhanced_pbp.data_nba.enhanced_pbp_item import (
    DataEnhancedPbpItem,
)


class DataJumpBall(JumpBall, DataEnhancedPbpItem):
    """
    Class for jump ball events
    """

    event_type = 10

    def __init__(self, *args):
        super().__init__(*args)



from pbpstats.resources.enhanced_pbp import EndOfPeriod
from pbpstats.resources.enhanced_pbp.stats_nba.enhanced_pbp_item import (
    StatsEnhancedPbpItem,
)


class StatsEndOfPeriod(EndOfPeriod, StatsEnhancedPbpItem):
    """
    Class for end of period events
    """

    event_type = 13

    def __init__(self, *args):
        super().__init__(*args)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pbpstats',
 'pbpstats.data_loader',
 'pbpstats.data_loader.data_nba',
 'pbpstats.data_loader.data_nba.boxscore',
 'pbpstats.data_loader.data_nba.enhanced_pbp',
 'pbpstats.data_loader.data_nba.pbp',
 'pbpstats.data_loader.data_nba.possessions',
 'pbpstats.data_loader.data_nba.schedule',
 'pbpstats.data_loader.live',
 'pbpstats.data_loader.live.boxscore',
 'pbpstats.data_loader.live.enhanced_pbp',
 'pbpstats.data_loader.live.pbp',
 'pbpstats.data_loader.live.possessions',
 'pbpstats.data_loader.stats_nba',
 'pbpstats.data_loader.stats_nba.boxscore',
 'pbpstats.data_loader.stats_nba.enhanced_pbp',
 'pbpstats.data_loader.stats_nba.game_finder',
 'pbpstats.data_loader.stats_nba.pbp',
 'pbpstats.data_loader.stats_nba.possessions',
 'pbpstats.data_loader.stats_nba.scoreboard',
 'pbpstats.data_loader.stats_nba.shots',
 'pbpstats.data_loader.stats_nba.summary',
 'pbpstats.objects',
 'pbpstats.resources',
 'pbpstats.resources.boxscore',
 'pbpstats.resources.enhanced_pbp',
 'pbpstats.resources.enhanced_pbp.data_nba',
 'pbpstats.resources.enhanced_pbp.live',
 'pbpstats.resources.enhanced_pbp.stats_nba',
 'pbpstats.resources.games',
 'pbpstats.resources.pbp',
 'pbpstats.resources.possessions',
 'pbpstats.resources.shots']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.27.1,<3.0.0']

setup_kwargs = {
    'name': 'pbpstats',
    'version': '1.3.6',
    'description': 'A package to scrape and parse NBA, WNBA and G-League play-by-play data',
    'long_description': None,
    'author': 'dblackrun',
    'author_email': 'darryl.blackport@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
